/**
 * OW2 geolocalization
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Add.java 5360 2010-02-24 14:29:45Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.util.geolocation.web.front;

import java.io.IOException;
import java.io.PrintWriter;
import javax.ejb.EJB;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.ow2.util.geolocation.business.GeoLocatorInterface;

/**
 * The service servlet to add a product in the app.
 * 
 * @author mancelin
 */
public class Add extends HttpServlet {
    /**
     * The geolocalization EJB.
     */
    @EJB
    private GeoLocatorInterface clientSess;

    /**
     * Handles the HTTP <code>GET</code> method.
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    @Override
    protected void doGet(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {
        doPut(request, response); // delete, just here for tests
    }

    @Override
    protected void doPost(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {
        doPut(request, response);
    }

    /** 
     * Handles the HTTP <code>POST</code> method.
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    @Override
    protected void doPut(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {
        String ipaddr = request.getRemoteAddr();
        String product = request.getParameter("product");
        String version = request.getParameter("version");
        String email = request.getParameter("email");
        String numProc = request.getParameter("numProc");
        String jreVersion = request.getParameter("jreVersion");
        String jreVendor = request.getParameter("jreVendor");
        String jvmVersion = request.getParameter("jvmVersion");
        String jvmVendor = request.getParameter("jvmVendor");
        String jvmName = request.getParameter("jvmName");
        String osName = request.getParameter("osName");
        String osArch = request.getParameter("osArch");
        String osVersion = request.getParameter("osVersion");
        if (ipaddr != null && product != null && version != null) {
            if (email == null) {
                email = "";
            }
            if (numProc == null) {
                numProc = "";
            }
            if (jreVersion == null) {
                jreVersion = "";
            }
            if (jreVendor == null) {
                jreVendor = "";
            }
            if (jvmVersion == null) {
                jvmVersion = "";
            }
            if (jvmVendor == null) {
                jvmVendor = "";
            }
            if (jvmName == null) {
                jvmName = "";
            }
            if (osName == null) {
                osName = "";
            }
            if (osArch == null) {
                osArch = "";
            }
            if (osVersion == null) {
                osVersion = "";
            }
            boolean resp = clientSess.addNewRecord(ipaddr, product, version, email,
                    numProc, jreVersion, jreVendor, jvmVersion, jvmVendor, jvmName,
                    osName, osArch, osVersion);
            response.setContentType("text/xml");
            PrintWriter out = response.getWriter();
            try {
                out.println("<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>");
                if (resp) {
                    out.println("<response action=\"addNewRecord\" success=\"true\" ipdaddr=\""
                            + ipaddr + "\" product=\"" + product + "\" version=\"" + version + "\"/>");
                } else {
                    out.println("<response action=\"addNewRecord\" success=\"false\" ipdaddr=\""
                            + ipaddr + "\" product=\"" + product + "\" version=\"" + version + "\"/>");
                }
            } finally {
                out.close();
            }
        }
    }

    /** 
     * Returns a short description of the servlet.
     * @return a String containing servlet description
     */
    @Override
    public String getServletInfo() {
        return "Short description";
    }
}
